@@ -30,16 +30,16 @@ summary.mcmcSamplerList <- function(object, ...){
 
   gelDiag <- gelmanDiagnostics(sampler)
   psf <- round(gelDiag$psrf[,1], 3)
-  
+
   mcmcsampler <- sampler[[1]]$settings$sampler
-  
+
   runtime <- 0
   for(i in 1:length(sampler)) runtime <- runtime+sampler[[i]]$settings$runtime[3]
 
   correlations <- round(cor(getSample(sampler)),3)
 
-  
-  sampler <- getSample(sampler, parametersOnly = T, coda = T)
+
+  sampler <- getSample(sampler, parametersOnly = T, coda = T, ...)
   if("mcmc.list" %in% class(sampler)){
     nrChain <- length(sampler)
     nrIter <- nrow(sampler[[1]])
@@ -72,20 +72,22 @@ summary.mcmcSamplerList <- function(object, ...){
     }
 
   }
-  
+
   # output for parameter metrics
   parOutDF <- cbind(psf, MAPvals, lowerq, medi, upperq)
   colnames(parOutDF) <- c("psf", "MAP", "2.5%", "median", "97.5%")
   row.names(parOutDF) <- parnames
 
-  
+
   cat(rep("#", 25), "\n")
   cat("## MCMC chain summary ##","\n")
   cat(rep("#", 25), "\n", "\n")
   cat("# MCMC sampler: ",mcmcsampler, "\n")
   cat("# Nr. Chains: ", nrChain, "\n")
   cat("# Iterations per chain: ", nrIter, "\n")
-  cat("# Rejection rate: ", round(mean(coda::rejectionRate(sampler)),3), "\n")
+  cat("# Rejection rate: ", ifelse(object[[1]]$setup$numPars == 1, # this is a hack because coda::rejectionRate does not work for 1-d MCMC lists
+                                   round(mean(sapply(sampler, coda::rejectionRate)),3),
+                                   round(mean(coda::rejectionRate(sampler)),3) ), "\n")
   cat("# Effective sample size: ", round(mean(coda::effectiveSize(sampler)),0), "\n")
   cat("# Runtime: ", runtime, " sec.","\n", "\n")
   cat("# Parameters\n")
@@ -95,7 +97,7 @@ summary.mcmcSamplerList <- function(object, ...){
   cat("## Convergence" ,"\n", "Gelman Rubin multivariate psrf: ", conv, "\n","\n")
   cat("## Correlations", "\n")
   print(correlations)
-  
+
 }
 
 #' @author Florian Hartig
@@ -117,10 +119,10 @@ plot.mcmcSamplerList <- function(x, ...){
 
 #' @author Florian Hartig
 #' @export
-getSample.mcmcSamplerList <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = 1, numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics, ...){
+getSample.mcmcSamplerList <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = 1, numSamples = NULL, whichParameters = NULL, reportDiagnostics, ...){
 
   if(!is.null(numSamples)) numSamples = ceiling(numSamples/length(sampler))
-  
+
   if(coda == F){
     # out = NULL
     out <- rep(list(NA), length(sampler))
@@ -140,12 +142,10 @@ getSample.mcmcSamplerList <- function(sampler, parametersOnly = T, coda = F, sta
       out[[i]] = getSample(sampler[[i]], parametersOnly = parametersOnly, coda = coda, start = start, end = end, thin = thin, numSamples = numSamples, whichParameters = whichParameters, reportDiagnostics= F)
     }
 
-    if(class(out[[1]]) == "mcmc.list") out = unlist(out, recursive = F)
+    if(inherits(out[[1]], "mcmc.list")) out = unlist(out, recursive = F)
     class(out) = "mcmc.list"
     out = out
   }
 
   return(out)
 }
-
-
